Extract the mentions - `@tags` - from a variable for a mention network with centrality measures.
Source:R/extract_mentions.R
extract_mentions.RdExtract the mentions - `@tags` - from a variable for a mention network with centrality measures.