Creates a tbl_graph object from a tibble containing mentioned authors and the authors who mentioend them.
Arguments
- dataset
A tibble where each row is a separate post.
- process
Choose "radarly" or "extract". Indicates whether mentions are already present in a Radarly export or should be extracted from the text.
- from
The variable containing the authors of a post.
- to
The variable containing authors who are mentioned in a post. If process = "extract", then this should be a raw text variable.
- size
The variable which should be represented by node size.
- colour
The variable which should be represented by node colour.
Examples
make_mention_network(
dataset = mention_example,
process = "radarly",
from = author,
to = mentions,
size = `twitter followers`,
colour = `estimated reach`
)
#> # A tbl_graph: 1277 nodes and 1332 edges
#> #
#> # A directed acyclic simple graph with 16 components
#> #
#> # Node Data: 1,277 × 3 (active)
#> node_name `mean_twitter followers` `mean_estimated reach`
#> <chr> <dbl> <dbl>
#> 1 160GHz NA NA
#> 2 1Michael2 NA NA
#> 3 1MoreUSA NA NA
#> 4 1kevinsime NA NA
#> 5 3errie NA NA
#> 6 4Scarrs_Gaming NA NA
#> 7 AAPNews NA NA
#> 8 ADTRAN NA NA
#> 9 AGT NA NA
#> 10 AK_REC NA NA
#> # ℹ 1,267 more rows
#> #
#> # Edge Data: 1,332 × 3
#> from to n_mentions
#> <int> <int> <int>
#> 1 20 309 1
#> 2 20 903 1
#> 3 20 914 1
#> # ℹ 1,329 more rows