A sample from the Radarly export that was used in the Microsoft Innovation project.
Format
A data frame with 1000 observations of 108 variables. The variables often used with make_mention_network() are:
- author
The twitter handle of sender of the post
- mentions
The twitter handle(s) of the account(s) that are mentioned in the post
- twitter followers
The number of followers of the account that sent the post
- estimated reach
The radarly estimated reach of the post