A sample from the formatted Sprinklr export that was used in the Microsoft Innovation project.
Format
A data frame with 1000 observations of 24 variables. The variables often used with make_retweet_network() are:
- OriginalAuthor
The twitter handle of original sender of the retweeted post
- sender_handle
The twitter handle of the account that retweeted the post
- followers
The number of followers of the account that retweeted the post
- Score
A custom metric intended to measure 'influence'