Create a mention network visualisation from the output of a ConnectR centrality function.
Source:R/viz_mention_centrality_network.R
viz_mention_centrality_network.RdCreate a mention network visualisation from the output of a ConnectR centrality function.
Usage
viz_mention_centrality_network(
centrality_frame,
from = from,
to = to,
size,
colour,
type = "interactive",
label_prop = 0.05,
directed = TRUE,
physics = FALSE,
...
)Arguments
- centrality_frame
The output of `ConnectR::calculate_centrality()` or `ConnectR::create_supercluster()`
- from
Author of post
- to
Mentioned user
- size
The variable by which nodes should be sized
- colour
The variable by which nodes should be coloured
- type
Whether an "interactive" or "static"
- label_prop
The proportion of node which should be labelled in a static graph
- directed
Whether the graph is directed or not - ought to be the same as the call to previous functions!
- physics
Whether to move nodes by physical laws or not - this can be time consuming
- ...
Arguments sent to `visNetwork::visNetwork()` e.g. `height = "900px", main = "[Graph title/headline]", submain = "[explanatory text]`